@@ -335,6 +335,13 @@ impl From<tokio::time::error::Elapsed> for Error {
     }
 }
 
+#[cfg(any(feature = "services", feature = "workers"))]
+impl From<tokio::task::JoinError> for Error {
+    fn from(e: tokio::task::JoinError) -> Error {
+        Error::failed(e)
+    }
+}
+
 impl From<std::convert::Infallible> for Error {
     fn from(_err: std::convert::Infallible) -> Error {
         panic!();
@@ -500,11 +507,11 @@ impl Error {
 
 impl std::fmt::Display for Error {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        let mut err = self.kind.to_string();
         if let Some(msg) = self.message.as_ref() {
-            err += &format!(": {}", msg);
+            write!(f, "{}: {}", self.kind, msg)
+        } else {
+            write!(f, "{}", self.kind)
         }
-        write!(f, "{}", err)
     }
 }
 
